import { Component, OnInit } from '@angular/core';
import {FormControl, Validators} from "@angular/forms";
import {AccountService} from "../../../../api";
import {Router} from "@angular/router";
import {AuthService} from "../../../auth.service";
import {MatSnackBar} from "@angular/material/snack-bar";

@Component({
  selector: 'app-delete-account',
  templateUrl: './delete-account.component.html',
  styleUrls: ['./delete-account.component.css']
})
export class DeleteAccountComponent implements OnInit {
  password: string = "";

  hide: boolean = true;
  passwordControl = new FormControl('', [Validators.required]);
  pending: boolean = false;

  constructor(private accountService: AccountService, private router: Router, private auth: AuthService, private snackbar: MatSnackBar) { }

  ngOnInit(): void {
  }

  onDelete() {
    this.pending = true;

    this.accountService.accountDeleteRequestPost({
      password: this.password
    }).subscribe({
      next: resp => {
        if(resp.status == "success") {
          this.pending = false;
          this.auth.clearAccessToken();
          this.router.navigate([''])
        }
      },
      error: err => {
        if(err.status == 409) {
          this.pending = false;
          this.snackbar.open("Invalid Password!", "", {duration: 2000})
        }
      }
    })
  }
}
